Learn R Programming

DynTxRegime (version 2.1)

plot: Generate Standard Plots

Description

Generate standard plots. This method uses the plot function as defined by the regression method used to obtain parameter estimates.

Usage

"plot"(x, y, ...)

Arguments

x
an object of class DynTxRegime.
y
ignored.
...
ignored.

Details

Titles and/or subtitles will automatically be appended with a character string indicating the regression model being plotted. This additional information can be suppressed using an optional argument "suppress = TRUE" in the call to plot