Learn R Programming

DynTxRegime (version 2.1)

propen: Retrieve Regression Objects for Propensity for Treatment

Description

Retrieve the value object returned by the propensity for treatment regression methods used in optimalClass and optimalSeq methods.

Usage

"propen"(object, ...)

Arguments

object
an object of class DynTxRegime.
...
ignored.

Value

Retrieves the value object returned by the regression method used to estimate the propensity for treatment. If multiple decision points or subset models were used, a list of objects is returned, where the kth element corresponds to the kth model.