Learn R Programming

DynTxRegime (version 2.1)

regimeCoef: Retrieve Regime Parameter Estimates

Description

Retrieves treatment regime parameter estimates from an object returned by optimalSeq.

Usage

"regimeCoef"(object, ...)

Arguments

object
an object of class DynTxRegime.
...
ignored.

Value

Retrieves the parameter estimates for the treatment rules as determined by the genetic algorithm of rgenoud.