"optTx"(x, newdata, ...)
"optTx"(x, newdata, ...)If newdata is provided, optTx estimates the optimal treatment for the new data based on the original analysis.
For optimalSeq, an optinal argument, dp, must be set, which indicates the stage of treatment for which the estimated optimal treatment is desired.