qqPlot: IQ-Learning: Generate QQ-Plots for Variance Modeling .
Description
Generate QQ plots for Variance modeling in IQ-Learning.
Usage
"qqPlot"(x, ...)
Arguments
x
an object of class DynTxRegime.
...
ignored.
Details
Generates a qq-plot for the variance modeling step of the IQ-Learning
algorithm. This plot is used to determine if the normal or empirical
density estimator is appropriate. If the observations deviate from the
line, den='nonpar' should be used in the final IQ-Learning step.